=========================
Salt 0.16.3 Release Notes
=========================

:release: 2013-08-09

Version 0.16.3 is another bugfix release for :doc:`0.16.0
</topics/releases/0.16.0>`. The changes include:

- Various documentation fixes
- Fix proc directory regression (:issue:`6502`)
- Properly detect Linaro_ Linux (:issue:`6496`)
- Fix regressions in :mod:`mount.mounted <salt.states.mount.mounted>`
  (:issue:`6522`, :issue:`6545`)
- Skip malformed state requisites (:issue:`6521`)
- Fix regression in gitfs from bad import
- Fix for watching prereq states (including recursive requisite error)
  (:issue:`6057`)
- Fix mod_watch not overriding prereq (:issue:`6520`)
- Don't allow functions which compile states to be called within states
  (:issue:`5623`)
- Return error for malformed top.sls (:issue:`6544`)
- Fix traceback in :mod:`mysql.query <salt.modules.mysql.query>`
- Fix regression in binary package installation for 64-bit packages
  on Debian-based Linux distros (:issue:`6563`)
- Fix traceback caused by running :mod:`cp.push <salt.modules.cp.push>` without
  having set :conf_master:`file_recv` in the master config file
- Fix scheduler configuration in pillar (:issue:`6201`)

.. _Linaro: http://www.linaro.org/
